/*global Util, Query, angular, Configuration*/
var Tco01200_ActionsValidator = function(ScreenService, General, ValidationEngine, eventAggregator, ZHPromise, ZhPreferences, ZhFilterPreferences, maskEngine, templateManager, ZhKeyboardService, MessageService) {

    /**
     * Verifica se o usuário pode usar a ação selecionada, olhando 
     * os parametros de situação e motivo.
     * 
     * @params {String} action - nome da ação acionada.
     * @params {Object} currentRow - objeto currentRow.
     * 
     * @return {Boolean} verdadeiro ou falso.
     **/

    this.verifyPermission = function(action, currentRow) {
        let allowed;
        let reason = currentRow.IDMOTIVO;
        let situation = currentRow.IDSERVICOPROPCOM;
        let params = getParamsByReason(reason);
        let situations = params.SITUATIONS;
        let msgError = params.MSGERROR;

        allowed = situations[situation].find(act => {
            return act === action;
        });

        if (allowed !== undefined) {
            return true;
        } else {
            MessageService.showMessageByCode(msgError);
            return false;
        }
    };

    /**
     * Decide qual objeto será retornado de acordo com o motivo filtrado.
     * 
     * @params {String} reason - nome do motivo filtrado.
     * 
     * @return {Object} objeto com os parâmetros que contem as ações permitidas
     * para cada situação e a respectiva mensagem de erro em caso de bloqueio.
     **/

    let getParamsByReason = function(reason) {
        if (reason === "SEMCARDBASE") {
            return {
                "SITUATIONS": {
                    NAOSOLICITADO: ["DETAILSERVICE", "DOWNLOAD", "SCOPE"],
                    AGUARDANDOPLANEJAMENTO: ["DETAILSERVICE", "FINISH", "RECUSE", "REQUEST", "RESPONSIBLE", "DOWNLOAD", "SCOPE"],
                    EMANDAMENTO: ["DETAILSERVICE", "FINISH", "RECUSE", "REQUEST", "DOWNLOAD", "RESPONSIBLE", "SCOPE"],
                    RECUSADO: ["DETAILSERVICE", "DOWNLOAD", "SCOPE"],
                    AGUARDANDOGN: ["DETAILSERVICE", "DOWNLOAD", "SCOPE"],
                    EMANDAMENTO_RETORNOGN: ["DETAILSERVICE", "FINISH", "RECUSE", "REQUEST", "DOWNLOAD", "RESPONSIBLE", "SCOPE"],
                    FINALIZADOPLANEJAMENTO: ["DETAILSERVICE", "DOWNLOAD", "SCOPE"],
                    CONCLUIDO: ["DETAILSERVICE", "DOWNLOAD", "SCOPE"],
                    APROVADO: ["DETAILSERVICE", "DOWNLOAD", "SCOPE"],
                    EFETIVADO: ["DETAILSERVICE", "DOWNLOAD", "SCOPE"]
                },
                "MSGERROR": "TCO01200_SEM_CARD_BASE"
            };
        } else {
            return {
                "SITUATIONS": {
                    NAOSOLICITADO: ["DETAILSERVICE", "CARDAPIO", "CONFIG", "ANALISE", "DOWNLOAD", "SCOPE"],
                    AGUARDANDOPLANEJAMENTO: ["DETAILSERVICE", "CARDAPIO", "FINISH", "RECUSE", "REQUEST", "RESPONSIBLE", "IMPORT", "CONFIG", "ANALISE", "DOWNLOAD", "SELECT_BRAND", "SCOPE", "COPIA_CARDAPIO_BASE"],
                    EMANDAMENTO: ["DETAILSERVICE", "CARDAPIO", "FINISH", "RECUSE", "REQUEST", "RESPONSIBLE", "IMPORT", "CONFIG", "ANALISE", "DOWNLOAD", "SELECT_BRAND", "SCOPE", "COPIA_CARDAPIO_BASE"],
                    RECUSADO: ["DETAILSERVICE", "CARDAPIO", "CONFIG", "ANALISE", "DOWNLOAD", "SCOPE"],
                    AGUARDANDOGN: ["DETAILSERVICE", "CARDAPIO", "CONFIG", "ANALISE", "DOWNLOAD", "SCOPE"],
                    EMANDAMENTO_RETORNOGN: ["DETAILSERVICE", "CARDAPIO", "FINISH", "RECUSE", "REQUEST", "RESPONSIBLE", "IMPORT", "CONFIG", "ANALISE", "DOWNLOAD", "SELECT_BRAND", "SCOPE"],
                    FINALIZADOPLANEJAMENTO: ["DETAILSERVICE", "CARDAPIO", "CONFIG", "ANALISE", "DOWNLOAD", "SCOPE"],
                    CONCLUIDO: ["DETAILSERVICE", "CARDAPIO", "CONFIG", "ANALISE", "DOWNLOAD", "SCOPE"],
                    APROVADO: ["DETAILSERVICE", "EFFECT", "CARDAPIO", "CONFIG", "ANALISE", "DOWNLOAD", "SCOPE"],
                    EFETIVADO: ["DETAILSERVICE", "CARDAPIO", "CONFIG", "ANALISE", "DOWNLOAD", "SCOPE"]
                },
                "MSGERROR": "TCO01200_ACTION_BLOCKED_BY_SITUATION"
            };
        }
    };

    /**
     * Verifica apenas as ações referentes ao cardápio.
     * 
     * @params {Object} filterRow - objeto filterRow.
     * 
     * @return {Boolean} verdadeiro ou falso.
     **/

    this.blockActionsCard = function(row) {
        let situation = row.IDSERVICOPROPCOM;
        let reason = row.IDMOTIVO;
        if (reason === "SEMCARDBASE") {
            MessageService.showMessageByCode("TCO01200_SEM_CARD_BASE");
            return false;
        } else {
            let allowedSituations = ["AGUARDANDOPLANEJAMENTO", "EMANDAMENTO_RETORNOGN", "EMANDAMENTO"];
            let allowed = allowedSituations.find(sit => {
                return sit === situation;
            });

            if (allowed !== undefined) {
                return true;
            } else {
                MessageService.showMessageByCode("TCO01200_ACTION_BLOCKED_BY_SITUATION");
                return false;
            }
        }
    };

};

Configuration(function(ContextRegister, eventEngine) {
    ContextRegister.register('Tco01200_ActionsValidator', Tco01200_ActionsValidator);
});
